/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: Elf32_Ehdr
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class Elf32_Ehdr {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _e_ehsizeOffset_;
	public static final int _e_entryOffset_;
	public static final int _e_flagsOffset_;
	public static final int _e_identOffset_;
	public static final int _e_machineOffset_;
	public static final int _e_phentsizeOffset_;
	public static final int _e_phnumOffset_;
	public static final int _e_phoffOffset_;
	public static final int _e_shentsizeOffset_;
	public static final int _e_shnumOffset_;
	public static final int _e_shoffOffset_;
	public static final int _e_shstrndxOffset_;
	public static final int _e_typeOffset_;
	public static final int _e_versionOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_e_ehsizeOffset_ = 0;
		_e_entryOffset_ = 0;
		_e_flagsOffset_ = 0;
		_e_identOffset_ = 0;
		_e_machineOffset_ = 0;
		_e_phentsizeOffset_ = 0;
		_e_phnumOffset_ = 0;
		_e_phoffOffset_ = 0;
		_e_shentsizeOffset_ = 0;
		_e_shnumOffset_ = 0;
		_e_shoffOffset_ = 0;
		_e_shstrndxOffset_ = 0;
		_e_typeOffset_ = 0;
		_e_versionOffset_ = 0;
	}

}
