/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: ExpandReason
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class ExpandReason {

	// VM Constants

	public static final long SIZEOF;
	public static final long EXPAND_DESPERATE;
	public static final long FORCED_NURSERY_EXPAND;
	public static final long FREE_SPACE_LESS_MINF;
	public static final long GC_RATIO_TOO_HIGH;
	public static final long NO_EXPAND;
	public static final long SATISFY_COLLECTOR;
	public static final long SCAV_RATIO_TOO_HIGH;


	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		EXPAND_DESPERATE = 0;
		FORCED_NURSERY_EXPAND = 0;
		FREE_SPACE_LESS_MINF = 0;
		GC_RATIO_TOO_HIGH = 0;
		NO_EXPAND = 0;
		SATISFY_COLLECTOR = 0;
		SCAV_RATIO_TOO_HIGH = 0;
	}

}
