/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_CycleState
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_CycleState {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __activeSubSpaceOffset_;
	public static final int __collectionStatisticsOffset_;
	public static final int __collectionTypeOffset_;
	public static final int __currentIncrementOffset_;
	public static final int __dynamicClassUnloadingEnabledOffset_;
	public static final int __externalCycleStateOffset_;
	public static final int __finalizationRequiredOffset_;
	public static final int __gcCodeOffset_;
	public static final int __markDelegateStateOffset_;
	public static final int __markMapOffset_;
	public static final int __noCompactionAfterSweepOffset_;
	public static final int __pgcData$_survivorSetRegionCountOffset_;
	public static final int __reasonForMarkCompactPGCOffset_;
	public static final int __referenceObjectOptionsOffset_;
	public static final int __shouldRunCopyForwardOffset_;
	public static final int __typeOffset_;
	public static final int __verboseContextIDOffset_;
	public static final int __workPacketsOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__activeSubSpaceOffset_ = 0;
		__collectionStatisticsOffset_ = 0;
		__collectionTypeOffset_ = 0;
		__currentIncrementOffset_ = 0;
		__dynamicClassUnloadingEnabledOffset_ = 0;
		__externalCycleStateOffset_ = 0;
		__finalizationRequiredOffset_ = 0;
		__gcCodeOffset_ = 0;
		__markDelegateStateOffset_ = 0;
		__markMapOffset_ = 0;
		__noCompactionAfterSweepOffset_ = 0;
		__pgcData$_survivorSetRegionCountOffset_ = 0;
		__reasonForMarkCompactPGCOffset_ = 0;
		__referenceObjectOptionsOffset_ = 0;
		__shouldRunCopyForwardOffset_ = 0;
		__typeOffset_ = 0;
		__verboseContextIDOffset_ = 0;
		__workPacketsOffset_ = 0;
	}

}
