/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_MemoryPoolAddressOrderedList
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_MemoryPoolAddressOrderedList {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __firstUnalignedFreeEntryOffset_;
	public static final int __heapFreeListOffset_;
	public static final int __heapLockOffset_;
	public static final int __hintActiveOffset_;
	public static final int __hintInactiveOffset_;
	public static final int __hintLruOffset_;
	public static final int __hintStorageOffset_;
	public static final int __largeObjectCollectorAllocateStatsOffset_;
	public static final int __prevFirstUnalignedFreeEntryOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__firstUnalignedFreeEntryOffset_ = 0;
		__heapFreeListOffset_ = 0;
		__heapLockOffset_ = 0;
		__hintActiveOffset_ = 0;
		__hintInactiveOffset_ = 0;
		__hintLruOffset_ = 0;
		__hintStorageOffset_ = 0;
		__largeObjectCollectorAllocateStatsOffset_ = 0;
		__prevFirstUnalignedFreeEntryOffset_ = 0;
	}

}
