/*******************************************************************************
 * Copyright (c) 1991, 2021 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: _libc_fpstate
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class _libc_fpstate {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __stOffset_;
	public static final int __xmmOffset_;
	public static final int _cwdOffset_;
	public static final int _fopOffset_;
	public static final int _ftwOffset_;
	public static final int _mxcr_maskOffset_;
	public static final int _mxcsrOffset_;
	public static final int _paddingOffset_;
	public static final int _rdpOffset_;
	public static final int _ripOffset_;
	public static final int _swdOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__stOffset_ = 0;
		__xmmOffset_ = 0;
		_cwdOffset_ = 0;
		_fopOffset_ = 0;
		_ftwOffset_ = 0;
		_mxcr_maskOffset_ = 0;
		_mxcsrOffset_ = 0;
		_paddingOffset_ = 0;
		_rdpOffset_ = 0;
		_ripOffset_ = 0;
		_swdOffset_ = 0;
	}

}
